==> klayout-0.9.tar.gz: klayout-0.9/src/ConfigurationDialogImpl.cc <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#include <QtGui/QDialog>
#include <QtGui/QVBoxLayout>
#include <QtGui/QMessageBox>

#include "ConfigurationDialogImpl.h"

#include "layMain.h"
#include "tlLog.h"
#include "dbHershey.h"

// -------------------------------------------------------------

ConfigurationDialogImpl::ConfigurationDialogImpl (QWidget *parent, lay::MainWindow *mw, lay::PluginDeclaration *decl, const char *name, Qt::WFlags fl)
  : QDialog (parent, name, FALSE, fl), Ui::ConfigurationDialog (),
    mp_main_window (mw)
{ 
  Ui::ConfigurationDialog::setupUi (this);

  //  signals and slots connections
  connect( ok_button, SIGNAL( clicked() ), this, SLOT( ok_clicked() ) );
  connect( cancel_button, SIGNAL( clicked() ), this, SLOT( reject() ) );

  QVBoxLayout *layout = new QVBoxLayout (centralFrame);

  std::string config_title;
  mp_config_page = decl->config_page (centralFrame, config_title);
  if (mp_config_page) {
    layout->addWidget (mp_config_page);
    mp_config_page->setup (mp_main_window);
  }

  setWindowTitle ((tl::translate ("Configuration") + " - " + config_title).c_str ());
}

void 
ConfigurationDialogImpl::commit () throw (tl::Exception)
{
  //  commit the custom config pages
  if (mp_config_page) {
    mp_config_page->commit (mp_main_window);
  }
  mp_main_window->config_end ();
}

void 
ConfigurationDialogImpl::ok_clicked ()
{
  try {
    commit ();
    accept ();
  } catch (tl::Exception &ex) {
    tl::error << ex.msg ();
    QMessageBox::critical (this, tl::translate ("Error").c_str (), ex.msg ().c_str ());
  } 
}

==> klayout-0.10.tar.gz: klayout-0.10/src/ConfigurationDialogImpl.cc <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#include <QtGui/QDialog>
#include <QtGui/QVBoxLayout>
#include <QtGui/QMessageBox>

#include "ConfigurationDialog.h"
#include "ConfigurationDialogImpl.h"
#include "ConfigurationDialog.h"

#include "layMainWindow.h"
#include "tlLog.h"
#include "dbHershey.h"

// -------------------------------------------------------------

ConfigurationDialogImpl::ConfigurationDialogImpl (QWidget *parent, lay::MainWindow *mw, lay::PluginDeclaration *decl, const char *name, Qt::WFlags fl)
  : QDialog (parent, name, FALSE, fl),
    mp_main_window (mw)
{ 
  mp_ui = new Ui::ConfigurationDialog ();
  mp_ui->setupUi (this);

  //  signals and slots connections
  connect( mp_ui->ok_button, SIGNAL( clicked() ), this, SLOT( ok_clicked() ) );
  connect( mp_ui->cancel_button, SIGNAL( clicked() ), this, SLOT( reject() ) );

  QVBoxLayout *layout = new QVBoxLayout (mp_ui->centralFrame);

  std::string config_title;
  mp_config_page = decl->config_page (mp_ui->centralFrame, config_title);
  if (mp_config_page) {
    layout->addWidget (mp_config_page);
    mp_config_page->setup (mp_main_window);
  }

  setWindowTitle ((tl::translate ("Configuration") + " - " + config_title).c_str ());
}

ConfigurationDialogImpl::~ConfigurationDialogImpl ()
{
  delete mp_ui;
  mp_ui = 0;
}

void 
ConfigurationDialogImpl::commit () throw (tl::Exception)
{
  //  commit the custom config pages
  if (mp_config_page) {
    mp_config_page->commit (mp_main_window);
  }
  mp_main_window->config_end ();
}

void 
ConfigurationDialogImpl::ok_clicked ()
{
  try {
    commit ();
    accept ();
  } catch (tl::Exception &ex) {
    tl::error << ex.msg ();
    QMessageBox::critical (this, tl::translate ("Error").c_str (), ex.msg ().c_str ());
  } 
}
